#!/bin/bash

# architect.sh: Work-in-progress implementation of the "architect" script
# Planned changes:
#  - Change naming scheme for yaml files, or the directory structure of the
#    repo, so that environments with the same name in different Conda
#    modules do not conflict
#  - Automatically commit changes to yaml files to repo (unless --no-commit
#    is set)
#  - Set default behavior to scan only environments from the most recent
#    Conda version (i.e., behave as "Inspector" unless --backup is used)

usage () {
    echo "$0 [options]
Export existing Conda environments as YAML files and push them to the
environment-yaml repo

OPTIONS

    -b | --backup
        Scan through old Anaconda3 environments instead of the most recent
        module path
    -n | --no-commit
        Create YAML files, but do not push them to the repo
    -h | --help
        Print this help message and exit
"
}

# Create YAMLs from all environments in the old Anaconda3 modules, e.g.
# /software/Anaconda3-5.3.0-el7-x86_64
backup_old_envs () {
    for modulepath in /software/Anaconda3*/envs/
    do
        for env in `ls $modulepath`
        do
            YAMLNAME="${env}_${DATESTR}.yaml"
            conda env export --prefix "$modulepath$env" > $OUTPATH/$YAMLNAME
        done
    done
}

OPTS=`getopt -o bhn --long backup,help,no-commit -n "$0" -- "$*"`
COMMIT=1
BACKUP=0

while true
do
    case "$1" in
        -b | --backup)
            BACKUP=1
            shift ;;
        -h | --help)
            usage
            exit 0
            ;;
        -n | --no-commit)
            COMMIT=0
            shift ;;
        --)
            shift
            break ;;
        *)
            break ;;
    esac
done

OUTPATH=./yaml
DATESTR=`date +'%m%d%Y'`
module load use.own miniconda

if [ $BACKUP -eq 1 ]
then
    backup_old_envs
else
    echo "Please run $0 -b"
fi
