#!/bin/bash

# contractor.sh: Work in progress script for restoring environments from YAML files.

usage () {
    echo "$0 [options] environments
Recreate Conda environments from their YAML files in the environment-yaml repo.

OPTIONS

    -r | --restore
        Attempt to recreate all environments from the repo.
    -d | --date
        Recreate environments as they existed on a given date. Date given in YYYY-MM-DD format.
    -h | --help
        Print this help message and exit
"
}


options=`getopt -o rd:h --long restore,date:,help -- "$@"`
[ $? -eq 0 ] || {
    echo "Invalid Options"
    usage
    exit 1
}
restore=0
date="latest"

eval set -- "$options"
while true; do
    case "$1" in
    -r | --restore)
        restore=1
        ;;
    -d | "--date")
        shift
        date="$1"
        ;;
    -h | --help)
        usage
        exit 0
        ;;
    --)
        shift
        break
        ;;
    esac
    shift
done

if [ "$date" != "latest" ]; then
    echo "---CHECKING OUT REQUESTED DAY---"
    git checkout `git rev-list -1 --before="$date" master`
else
    echo "---CHECKING OUT MASTER---"
    git checkout master
fi

if [ $restore -eq 1 ]; then
    echo "---RESTORING ALL ENVIRONMENTS---"
    cd yaml
    envs=(*.yaml)
    cd ..
else
    echo "---RESTORING SELECTED ENVIRONMENTS---"
    envs=("${@/%/.yaml}")
    echo "${#envs[@]} Environments to Restore:"
    echo ${envs[@]}
fi

listed=`conda env list`

cd yaml

for env in "${envs[@]}"
do
    if echo "$listed" | grep -q "^${env%.*}[[:space:]].*$"; then
        conda env update --name $env$.* --file $env --prume
    else
        conda env create --name $env$.* --file $env
    fi
done

cd ..

echo "---CHECKING OUT MASTER---"
git checkout master
